@@ -23,7 +23,7 @@
 #include "graphtree_defines.h"
 #include "tdesvnsettings.h"
 #include "stopdlg.h"
-#include "client.hpp"
+#include "client.h"
 
 #include <kapp.h>
 #include <kdebug.h>
