@@ -37,17 +37,17 @@
 #include "revisiontree.h"
 #include "tdesvnsettings.h"
 #include "tdesvn_events.h"
-#include "client.hpp"
-#include "annotate_line.hpp"
-#include "context_listener.hpp"
-#include "dirent.hpp"
-#include "targets.hpp"
-#include "url.hpp"
-#include "wc.hpp"
-#include "svnqt_defines.hpp"
-#include "LogCache.hpp"
-#include "ReposLog.hpp"
-#include "url.hpp"
+#include "client.h"
+#include "annotate_line.h"
+#include "context_listener.h"
+#include "dirent.h"
+#include "targets.h"
+#include "url.h"
+#include "wc.h"
+#include "svnqt_defines.h"
+#include "LogCache.h"
+#include "ReposLog.h"
+#include "url.h"
 
 #include "helpers/sub2qt.h"
 #include "fronthelpers/cursorstack.h"
