@@ -33,18 +33,18 @@
 
 
 // svncpp
-#include "svnqt/client_impl.hpp"
+#include "svnqt/client_impl.h"
 
 // subversion api
 #include "svn_client.h"
 #include "svn_path.h"
 //#include "svn_utf.h"
 
-#include "svnqt/dirent.hpp"
-#include "svnqt/exception.hpp"
-#include "svnqt/svnqt_defines.hpp"
+#include "svnqt/dirent.h"
+#include "svnqt/exception.h"
+#include "svnqt/svnqt_defines.h"
 
-#include "svnqt/helper.hpp"
+#include "svnqt/helper.h"
 
 namespace svn
 {
