@@ -31,18 +31,18 @@
 #pragma warning( disable: 4786 )// debug symbol truncated
 #endif
 // svncpp
-#include "svnqt/client_impl.hpp"
+#include "svnqt/client_impl.h"
 
 // subversion api
 #include "svn_client.h"
 
-#include "svnqt/exception.hpp"
-#include "svnqt/pool.hpp"
-#include "svnqt/targets.hpp"
-#include "svnqt/svnqt_defines.hpp"
-#include "svnqt/stringarray.hpp"
+#include "svnqt/exception.h"
+#include "svnqt/pool.h"
+#include "svnqt/targets.h"
+#include "svnqt/svnqt_defines.h"
+#include "svnqt/stringarray.h"
 
-#include "svnqt/helper.hpp"
+#include "svnqt/helper.h"
 
 namespace svn
 {
