@@ -32,10 +32,10 @@
 #include "svn_wc.h"
 
 // svncpp
-#include "exception.hpp"
-#include "path.hpp"
-#include "pool.hpp"
-#include "wc.hpp"
+#include "exception.h"
+#include "path.h"
+#include "pool.h"
+#include "wc.h"
 
 namespace svn
 {
