@@ -28,8 +28,8 @@
 #include "cmdexecsettings_impl.h"
 #include "tdesvnview.h"
 #include "commandline_part.h"
-#include "version_check.hpp"
-#include "url.hpp"
+#include "version_check.h"
+#include "url.h"
 #include "helpers/ktranslateurl.h"
 #include "helpers/sshagent.h"
 
